# ABC Class Reference

## **Avatar**

::: presencedb.abc.Avatar

## **TopUser**

::: presencedb.abc.TopUser

## **TopActivity**

::: presencedb.abc.TopActivity

## **UserTopActivity**

::: presencedb.abc.UserTopActivity

## **TrendingActivity**

::: presencedb.abc.TrendingActivity

## **UserTrendingActivity**

::: presencedb.abc.UserTrendingActivity

## **PlaytimeDate**

::: presencedb.abc.PlaytimeDate
